/**
 * Copyright (c) 2000-2007 Liferay, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.liferay.portlet.journal.action;

import com.liferay.portal.kernel.util.Constants;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.security.auth.PrincipalException;
import com.liferay.portal.struts.PortletAction;
import com.liferay.portal.theme.ThemeDisplay;
import com.liferay.portlet.journal.NoSuchShortcutException;
import com.liferay.portlet.journal.NoSuchStructureException;
import com.liferay.portlet.journal.ShortcutPermissionException;
import com.liferay.portlet.journal.RequiredLinkException;
import com.liferay.portlet.journal.service.JournalLinkServiceUtil;
import com.liferay.portlet.journal.service.LinkType;
import com.liferay.util.servlet.SessionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import javax.portlet.*;

/**
 * <a href="EditFileShortcutAction.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class EditStructureShortcutAction extends PortletAction {

    public void processAction(
            ActionMapping mapping, ActionForm form, PortletConfig config,
            ActionRequest req, ActionResponse res)
            throws Exception {

        String cmd = ParamUtil.getString(req, Constants.CMD);

        try {
            if (cmd.equals(Constants.ADD) || cmd.equals(Constants.UPDATE)) {
                updateStructureShortcut(req);
            } else if (cmd.equals(Constants.DELETE)) {
                deleteStructureShortcut(req);
            }

            sendRedirect(req, res);
        }
        catch (Exception e) {
            if (e instanceof NoSuchShortcutException ||
                    e instanceof RequiredLinkException ||                    
                    e instanceof PrincipalException) {

                SessionErrors.add(req, e.getClass().getName());

                setForward(req, "portlet.journal.error");
            } else if (e instanceof ShortcutPermissionException ||
                    e instanceof NoSuchStructureException) {

                SessionErrors.add(req, e.getClass().getName());
            } else {
                throw e;
            }
        }
    }

    public ActionForward render(
            ActionMapping mapping, ActionForm form, PortletConfig config,
            RenderRequest req, RenderResponse res)
            throws Exception {

        try {
            ActionUtil.getStructureShortcut(req);
        }
        catch (Exception e) {
            if (e instanceof NoSuchShortcutException ||
                    e instanceof PrincipalException) {

                SessionErrors.add(req, e.getClass().getName());

                return mapping.findForward("portlet.journal.error");
            } else {
                throw e;
            }
        }

        return mapping.findForward(
                getForward(req, "portlet.journal.edit_structure_shortcut"));
    }

    protected void deleteStructureShortcut(ActionRequest req) throws Exception {
        long shortcutId = ParamUtil.getLong(req, "shortcutId");
        JournalLinkServiceUtil.removeLink(shortcutId);
    }

    protected void updateStructureShortcut(ActionRequest req) throws Exception {
        long shortcutId = ParamUtil.getLong(req, "shortcutId");

        ThemeDisplay theme = (ThemeDisplay) req.getAttribute("THEME_DISPLAY");
        long plid = theme.getPlid();
        long userId = theme.getUserId();
        long groupId = ParamUtil.getLong(req, "groupId");
        long targetGroupId = ParamUtil.getLong(req, "targetGroupId");
        String targetId = ParamUtil.getString(req, "targetId");

        String[] communityPermissions = req.getParameterValues("communityPermissions");
        String[] guestPermissions = req.getParameterValues("guestPermissions");

        if (shortcutId <= 0) {
            // Add file shortcut
            JournalLinkServiceUtil.addLink(userId,LinkType.STRUCTURE, plid, groupId, targetGroupId, targetId, communityPermissions, guestPermissions);
        } else {
            // Update file shortcut
            JournalLinkServiceUtil.updateLink(shortcutId, targetGroupId, targetId);
        }
    }

}