package com.liferay.portlet.journal.action;

import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.security.auth.PrincipalException;
import com.liferay.portal.struts.PortletAction;
import com.liferay.portal.theme.ThemeDisplay;
import com.liferay.portal.kernel.util.Constants;
import com.liferay.portlet.journal.NoSuchShortcutException;
import com.liferay.portlet.journal.NoSuchTemplateException;
import com.liferay.portlet.journal.ShortcutPermissionException;
import com.liferay.portlet.journal.RequiredLinkException;
import com.liferay.portlet.journal.service.JournalLinkServiceUtil;
import com.liferay.portlet.journal.service.LinkType;
import com.liferay.util.servlet.SessionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import javax.portlet.*;

/**
 * <a href="EditFileShortcutAction.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class EditTemplateShortcutAction extends PortletAction {

    public void processAction(
            ActionMapping mapping, ActionForm form, PortletConfig config,
            ActionRequest req, ActionResponse res)
            throws Exception {

        String cmd = ParamUtil.getString(req, Constants.CMD);

        try {
            if (cmd.equals(Constants.ADD) || cmd.equals(Constants.UPDATE)) {
                updateTemplateShortcut(req);
            } else if (cmd.equals(Constants.DELETE)) {
                deleteTemplateShortcut(req);
            }

            sendRedirect(req, res);
        }
        catch (Exception e) {
            if (e instanceof NoSuchShortcutException ||
                    e instanceof PrincipalException) {

                SessionErrors.add(req, e.getClass().getName());

                setForward(req, "portlet.journal.error");
            } else if (e instanceof ShortcutPermissionException ||
                     e instanceof RequiredLinkException || 
                    e instanceof NoSuchTemplateException ) {

                SessionErrors.add(req, e.getClass().getName());
            } else {
                throw e;
            }
        }
    }

    public ActionForward render(
            ActionMapping mapping, ActionForm form, PortletConfig config,
            RenderRequest req, RenderResponse res)
            throws Exception {

        try {
            ActionUtil.getTemplateShortcut(req);
        }
        catch (Exception e) {
            if (e instanceof com.liferay.portlet.journal.NoSuchShortcutException ||
                e instanceof com.liferay.portlet.journal.RequiredLinkException ||
                    e instanceof PrincipalException) {

                SessionErrors.add(req, e.getClass().getName());

                return mapping.findForward("portlet.journal.error");
            } else {
                throw e;
            }
        }

        return mapping.findForward(
                getForward(req, "portlet.journal.edit_template_shortcut"));
    }

    protected void deleteTemplateShortcut(ActionRequest req) throws Exception {
        long shortcutId = ParamUtil.getLong(req, "shortcutId");
        JournalLinkServiceUtil.removeLink(shortcutId);
    }

    protected void updateTemplateShortcut(ActionRequest req) throws Exception {
        long shortcutId = ParamUtil.getLong(req, "shortcutId");

        ThemeDisplay theme = (ThemeDisplay) req.getAttribute("THEME_DISPLAY");
        long plid = theme.getPlid();
        long userId = theme.getUserId();
        long groupId = ParamUtil.getLong(req, "groupId");
        long targetGroupId = ParamUtil.getLong(req, "targetGroupId");
        String targetId = ParamUtil.getString(req, "targetId");

        String[] communityPermissions = req.getParameterValues("communityPermissions");
        String[] guestPermissions = req.getParameterValues("guestPermissions");

        if (shortcutId <= 0) {
            // Add file shortcut
            JournalLinkServiceUtil.addLink(userId,LinkType.TEMPLATE,plid,groupId, targetGroupId, targetId, communityPermissions, guestPermissions);
        } else {
            // Update file shortcut
            JournalLinkServiceUtil.updateLink(shortcutId, targetGroupId, targetId);
        }
    }

}
