package com.liferay.portlet.journal.service.impl;

import com.liferay.counter.service.CounterLocalServiceUtil;
import com.liferay.portal.PortalException;
import com.liferay.portal.SystemException;
import com.liferay.portal.model.impl.ResourceImpl;
import com.liferay.portal.model.User;
import com.liferay.portal.service.ResourceLocalServiceUtil;
import com.liferay.portal.service.persistence.UserUtil;
import com.liferay.portlet.journal.model.JournalLink;
import com.liferay.portlet.journal.service.*;
import com.liferay.portlet.journal.service.base.JournalLinkLocalServiceBaseImpl;
import com.liferay.portlet.journal.service.persistence.JournalLinkUtil;
import com.liferay.portlet.journal.service.persistence.JournalArticleUtil;
import com.liferay.portlet.journal.RequiredStructureException;
import com.liferay.portlet.journal.RequiredTemplateException;
import com.liferay.portlet.journal.RequiredLinkException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.List;
import java.rmi.RemoteException;

/**
 * <a href="JournalArticleLocalServiceImpl.java.html"><b><i>View Source</i></b>
 * </a>
 *
 * @author Brian Wing Shun Chan
 */
public class JournalLinkLocalServiceImpl extends JournalLinkLocalServiceBaseImpl {

    public JournalLink addLink(long userId, LinkType linkType, long groupId, String targetId, long targetGroupId, String[] addCommunityPermissions, String[] addGuestPermissions) throws PortalException, SystemException {
        return addLink(userId,
                linkType, groupId, targetId, targetGroupId,
                null, null, addCommunityPermissions,
                addGuestPermissions);
    }

    public JournalLink addLink(long userId,
                               LinkType linkType,
                               long groupId,
                               String targetId,
                               long targetGroupId,
                               Boolean addCommunityPermissions,
                               Boolean addGuestPermissions,
                               String[] communityPermissions,
                               String[] guestPermissions) throws PortalException, SystemException {

        long id = CounterLocalServiceUtil.increment();

        User user = UserUtil.findByPrimaryKey(userId);

        JournalLink link = JournalLinkUtil.create(id);

        if (linkType.equals(LinkType.STRUCTURE)) {
            try {
                JournalStructureServiceUtil.getStructure(targetGroupId, targetId);
            } catch (RemoteException e) {
                e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
            }
        }
        if (linkType.equals(LinkType.TEMPLATE)) {
            try {
                JournalTemplateServiceUtil.getTemplate(targetGroupId, targetId);
            } catch (RemoteException e) {
                e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
            }
        }

        link.setGroupId(groupId);
        link.setTargetGroupId(targetGroupId);
        link.setTargetId(targetId);
        link.setPrimaryKey(id);
        link.setUserId(userId);
        link.setCompanyId(user.getCompanyId());
        link.setLinkType(linkType.getType());
        JournalLinkUtil.update(link);

        // Resources

        if ((addCommunityPermissions != null) &&
                (addGuestPermissions != null)) {

            addLinkResources(
                    link, addCommunityPermissions.booleanValue(),
                    addGuestPermissions.booleanValue());
        } else {
            addLinkResources(
                    link,
                    communityPermissions, guestPermissions);
        }

        return link;
    }


    public void addLinkResources(
            JournalLink link, boolean addCommunityPermissions,
            boolean addGuestPermissions)
            throws PortalException, SystemException {

        ResourceLocalServiceUtil.addResources(
                link.getCompanyId(), link.getGroupId(),
                link.getUserId(), JournalLink.class.getName(),
                link.getId(), false, addCommunityPermissions,
                addGuestPermissions);
    }


    public void addLinkResources(
            JournalLink link, String[] communityPermissions,
            String[] guestPermissions)
            throws PortalException, SystemException {

        ResourceLocalServiceUtil.addModelResources(
                link.getCompanyId(), link.getGroupId(),
                link.getUserId(), JournalLink.class.getName(),
                link.getId(), communityPermissions, guestPermissions);
    }


    public void deleteLink(JournalLink link) throws PortalException, SystemException {
        long linkType = link.getLinkType();
        if (linkType==LinkType.STRUCTURE.getType()){
        if (JournalArticleUtil.countByG_S(
                link.getGroupId(), link.getTargetId()) > 0) {

            throw new RequiredLinkException();
        }
        }
        if (linkType==LinkType.TEMPLATE.getType()){
        if (JournalArticleUtil.countByG_T(
                link.getGroupId(), link.getTargetId()) > 0) {

            throw new RequiredLinkException();
        }
        }

/*
        if (JournalLinkUtil.countByG_T(link.getGroupId(), link.getTargetId()) > 0) {

            throw new RequiredStructureException();
        }*/
        // Resources
        ResourceLocalServiceUtil.deleteResource(
                link.getCompanyId(), JournalLink.class.getName(),
                ResourceImpl.SCOPE_INDIVIDUAL, link.getId());

        JournalLinkUtil.remove(link.getPrimaryKey());
    }

    public JournalLink updateLink(JournalLink link) throws SystemException, PortalException {
        return JournalLinkUtil.update(link);
    }

    public JournalLink getLink(long linkId) throws SystemException, PortalException {
        return JournalLinkUtil.fetchByPrimaryKey(linkId);
    }

    public List getAllLinks(LinkType linkType, long groupId) throws SystemException {
        return JournalLinkUtil.fetchByGroupId(linkType, groupId);
    }

    public List getAllLinksByTarget(LinkType linkType, long targetGroupId, String targetId) throws SystemException {
        return JournalLinkUtil.getAllLinksByTarget(linkType, targetGroupId, targetId);
    }

    public JournalLink getLink(String deleteStructureId, long groupId) throws SystemException {
        return JournalLinkUtil.fetchByTargetIdAndGroupId(deleteStructureId, groupId);
    }


    private static Log _log = LogFactory.getLog(JournalLinkLocalServiceImpl.class);

}
