package com.liferay.portlet.journal.service.impl;

import com.liferay.portal.PortalException;
import com.liferay.portal.SystemException;
import com.liferay.portal.kernel.security.permission.ActionKeys;
import com.liferay.portal.service.impl.PrincipalBean;
import com.liferay.portal.service.permission.PortletPermissionUtil;
import com.liferay.portal.util.PortletKeys;
import com.liferay.portlet.journal.model.JournalLink;
import com.liferay.portlet.journal.service.JournalLinkLocalServiceUtil;
import com.liferay.portlet.journal.service.JournalLinkService;
import com.liferay.portlet.journal.service.LinkType;
import com.liferay.portlet.journal.service.permission.JournalLinkPermission;

/**
 * <a href="JournalArticleLinkServiceImpl.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class JournalLinkServiceImpl extends PrincipalBean implements JournalLinkService {

    public JournalLink addLink(long userId, LinkType linkType,long plid, long groupId, String targetId, long targetGroupId , String[] addCommunityPermissions,
		String[] addGuestPermissions) throws PortalException, SystemException {
       PortletPermissionUtil.check(getPermissionChecker(), plid, PortletKeys.JOURNAL,ActionKeys.ADD_SHORTCUT);
        return JournalLinkLocalServiceUtil.addLink(userId,linkType,groupId, targetId, targetGroupId,addCommunityPermissions,addGuestPermissions);
    }

    public JournalLink getLink(long linkId) throws PortalException, SystemException {
        JournalLinkPermission.check(getPermissionChecker(), linkId, ActionKeys.VIEW);
        return JournalLinkLocalServiceUtil.getLink(linkId);
    }

    public JournalLink getLinkByTargetIdAndGroupId(String deleteStructureId, long groupId) throws SystemException, PortalException {
        JournalLinkPermission.check(getPermissionChecker(), deleteStructureId,groupId, ActionKeys.VIEW);
        return JournalLinkLocalServiceUtil.getLink(deleteStructureId,groupId);
    }

    public void deleteLink(long linkId) throws PortalException, SystemException {
        JournalLinkPermission.check(getPermissionChecker(), linkId, ActionKeys.DELETE);
        JournalLinkLocalServiceUtil.deleteLink(linkId);
    }

    public JournalLink updateLink(long linkId, String targetId, long targetGroupId) throws PortalException, SystemException {
        JournalLinkPermission.check(getPermissionChecker(), linkId, ActionKeys.UPDATE);
        return JournalLinkLocalServiceUtil.updateLink(linkId, targetId, targetGroupId);
    }


}
