package com.liferay.portlet.journal.service.permission;

import com.liferay.portal.PortalException;
import com.liferay.portal.SystemException;
import com.liferay.portal.kernel.security.permission.PermissionChecker;
import com.liferay.portal.security.auth.PrincipalException;
import com.liferay.portlet.journal.model.JournalArticle;
import com.liferay.portlet.journal.model.JournalLink;
import com.liferay.portlet.journal.service.JournalLinkLocalServiceUtil;

/**
 * <a href="JournalArticlePermission.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class JournalLinkPermission {

    public static void check(PermissionChecker permissionChecker, long linkId, String actionId)
            throws PortalException, SystemException {
        if (!contains(permissionChecker, linkId, actionId)) {
            throw new PrincipalException();
        }
    }

    public static void check(PermissionChecker permissionChecker, JournalLink article, String actionId)
            throws PortalException, SystemException {
        if (!contains(permissionChecker, article, actionId)) {
            throw new PrincipalException();
        }
    }

    public static boolean contains(PermissionChecker permissionChecker, long linkId, String actionId)
            throws PortalException, SystemException {
        JournalLink link = JournalLinkLocalServiceUtil.getLink(linkId);
        return contains(permissionChecker, link, actionId);
    }

    public static boolean contains(PermissionChecker permissionChecker, JournalLink link, String actionId)
            throws PortalException, SystemException {
        return permissionChecker.hasPermission(link.getGroupId(), JournalLink.class.getName(), link.getId(), actionId);
    }

    public static void check(PermissionChecker permissionChecker, String deleteStructureId, long groupId, String actionId) throws PortalException, SystemException {
        if (!contains(permissionChecker, deleteStructureId,groupId, actionId)) {
            throw new PrincipalException();
        }
    }

    private static boolean contains(PermissionChecker permissionChecker, String deleteStructureId, long groupId, String actionId) throws SystemException, PortalException {
       JournalLink link = JournalLinkLocalServiceUtil.getLink(deleteStructureId,groupId);
        return contains(permissionChecker, link, actionId);
    }
}
