package com.liferay.portlet.journal.service.persistence;

import com.liferay.portal.SystemException;
import com.liferay.portal.kernel.util.StringMaker;
import com.liferay.portal.kernel.util.StringPool;
import com.liferay.portal.service.persistence.BasePersistence;
import com.liferay.portal.spring.hibernate.HibernateUtil;
import com.liferay.portlet.journal.NoSuchArticleException;
import com.liferay.portlet.journal.model.JournalArticleExternalData;
import com.liferay.portlet.journal.model.impl.JournalArticleExternalDataImpl;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Query;
import org.hibernate.Session;

import java.util.List;

/**
 * <a href="JournalArticlePersistenceImpl.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class JournalArticleExternalDataPersistenceImpl extends BasePersistence
        implements JournalArticleExternalDataPersistence {
    public JournalArticleExternalData create(long id) {
        JournalArticleExternalData journalArticleExternalData = new JournalArticleExternalDataImpl();
        journalArticleExternalData.setNew(true);
        journalArticleExternalData.setPrimaryKey(id);

        return journalArticleExternalData;
    }

    public JournalArticleExternalData remove(long id)
            throws NoSuchArticleException, SystemException {
        Session session = null;

        try {
            session = openSession();

            JournalArticleExternalData journalArticleExternalData = (JournalArticleExternalData) session.get(JournalArticleExternalDataImpl.class,
                    new Long(id));

            if (journalArticleExternalData == null) {
                if (_log.isWarnEnabled()) {
                    _log.warn("No JournalArticle exists with the primary key " +
                            id);
                }

                throw new NoSuchArticleException(
                        "No JournalArticle exists with the primary key " + id);
            }

            return remove(journalArticleExternalData);
        }
        catch (NoSuchArticleException nsee) {
            throw nsee;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public JournalArticleExternalData remove(JournalArticleExternalData journalArticle)
            throws SystemException {
        Session session = null;

        try {
            session = openSession();
            session.delete(journalArticle);
            session.flush();

            return journalArticle;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public JournalArticleExternalData update(
            JournalArticleExternalData journalArticle)
            throws SystemException {
        return update(journalArticle, false);
    }

    public JournalArticleExternalData update(
            JournalArticleExternalData journalArticle,
            boolean saveOrUpdate) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            if (saveOrUpdate) {
                session.saveOrUpdate(journalArticle);
            } else {
                if (journalArticle.isNew()) {
                    session.save(journalArticle);
                }
            }

            session.flush();
            journalArticle.setNew(false);

            return journalArticle;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }


    public JournalArticleExternalData findByG_A(long groupId, String articleId ) throws NoSuchArticleException, SystemException {
      JournalArticleExternalData journalArticleExternalData = fetchByG_A(groupId, articleId);

        if (journalArticleExternalData == null) {
            StringMaker msg = new StringMaker();
            msg.append("No JournalArticleExternalData exists with the key ");
            msg.append(StringPool.OPEN_CURLY_BRACE);
            msg.append("groupId=");
            msg.append(groupId);
            msg.append(", ");
            msg.append("articleId=");
            msg.append(articleId);

            msg.append(StringPool.CLOSE_CURLY_BRACE);

            if (_log.isWarnEnabled()) {
                _log.warn(msg.toString());
            }

            throw new NoSuchArticleException(msg.toString());
        }

        return journalArticleExternalData;

    }

    public JournalArticleExternalData fetchByG_A(long groupId, String articleId) throws SystemException {
        Session session = null;
        try {
            session = openSession();

            StringMaker query = new StringMaker();
            query.append(
                    "FROM com.liferay.portlet.journal.model.JournalArticleExternalData WHERE ");
            query.append("groupId = ?");
            query.append(" AND ");

            if (articleId == null) {
                query.append("articleId IS NULL");
            } else {
                query.append("articleId = ?");
            }
            query.append(" ");
            query.append("ORDER BY ");
            query.append("articleId ASC");

            Query q = session.createQuery(query.toString());
            q.setCacheable(true);

            int queryPos = 0;
            q.setLong(queryPos++, groupId);

            if (articleId != null) {
                q.setString(queryPos++, articleId);
            }


            List list = q.list();

            if (list.size() == 0) {
                return null;
            }

            JournalArticleExternalData journalArticleExternalData = (JournalArticleExternalData) list.get(0);

            return journalArticleExternalData;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }


    public JournalArticleExternalData findByPrimaryKey(long id)
            throws NoSuchArticleException, SystemException {
        JournalArticleExternalData journalArticleExternalData = fetchByPrimaryKey(id);

        if (journalArticleExternalData == null) {
            if (_log.isWarnEnabled()) {
                _log.warn("No JournalArticle exists with the primary key " +
                        id);
            }

            throw new NoSuchArticleException(
                    "No JournalArticle exists with the primary key " + id);
        }

        return journalArticleExternalData;
    }


    public JournalArticleExternalData fetchByPrimaryKey(long id) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            return (JournalArticleExternalData) session.get(JournalArticleExternalDataImpl.class,
                    new Long(id));
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public void removeByArticleExternalDataId(long groupId) throws SystemException, NoSuchArticleException {
        JournalArticleExternalData journalArticle = findByPrimaryKey(groupId);
        remove(journalArticle);
    }

    protected void initDao() {
    }

    private static Log _log = LogFactory.getLog(JournalArticleExternalDataPersistenceImpl.class);
}
