package com.liferay.portlet.journal.service.persistence;

import com.liferay.portal.SystemException;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.kernel.util.StringMaker;
import com.liferay.portal.service.persistence.BasePersistence;
import com.liferay.portal.spring.hibernate.HibernateUtil;
import com.liferay.portlet.journal.NoSuchShortcutException;
import com.liferay.portlet.journal.model.JournalLink;
import com.liferay.portlet.journal.model.impl.JournalLinkImpl;
import com.liferay.portlet.journal.service.LinkType;
import com.liferay.util.dao.hibernate.QueryUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Query;
import org.hibernate.Session;

import java.util.List;
import java.util.Iterator;

/**
 * <a href="JournalArticlePersistenceImpl.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class JournalLinkPersistenceImpl extends BasePersistence implements JournalLinkPersistence {
    public JournalLink create(long id) {
        JournalLink journalLink = new JournalLinkImpl();
        journalLink.setNew(true);
        journalLink.setPrimaryKey(id);

        return journalLink;
    }

    public JournalLink remove(long id)
            throws SystemException, NoSuchShortcutException {
        Session session = null;

        try {
            session = openSession();

            JournalLink journalLink = (JournalLink) session.get(JournalLinkImpl.class,
                    new Long(id));

            if (journalLink == null) {
                if (_log.isWarnEnabled()) {
                    _log.warn("No JournalLink exists with the primary key " +
                            id);
                }

                throw new NoSuchShortcutException(
                        "No JournalLink exists with the primary key " + id);
            }

            return remove(journalLink);
        }
        catch (NoSuchShortcutException nsse) {
            throw nsse;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public JournalLink remove(JournalLink journal)
            throws SystemException {
        Session session = null;

        try {
            session = openSession();
            session.delete(journal);
            session.flush();

            return journal;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public JournalLink update(
            JournalLink journal)
            throws SystemException {
        return update(journal, false);
    }

    public JournalLink update(
            JournalLink journal,
            boolean saveOrUpdate) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            if (saveOrUpdate) {
                session.saveOrUpdate(journal);
            } else {
                if (journal.isNew()) {
                    session.save(journal);
                }
            }

            session.flush();
            journal.setNew(false);

            return journal;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public List findByGroupId(LinkType linkType, long groupId) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            StringMaker query = new StringMaker();
            query.append(
                    "FROM com.liferay.portlet.journal.model.JournalLink WHERE ");
            query.append("groupId = ?");
            query.append(" AND ");
            query.append("linkType = ?");
            query.append(" ");
            query.append("ORDER BY ");
            query.append("targetId ASC");

            Query q = session.createQuery(query.toString());
            q.setCacheable(true);

            int queryPos = 0;
            q.setLong(queryPos++, groupId);
            q.setLong(queryPos++, linkType.getType());

            return q.list();
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public List findByGroupId(LinkType linkType, long groupId, int begin, int end)
            throws SystemException {
        return findByGroupId(linkType, groupId, begin, end, null);
    }

    public List findByGroupId(LinkType linkType, long groupId, int begin, int end,
                              OrderByComparator obc) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            StringMaker query = new StringMaker();
            query.append(
                    "FROM com.liferay.portlet.journal.model.JournalLink WHERE ");
            query.append("groupId = ?");
            query.append(" AND ");
            query.append("linkType = ?");
            query.append(" ");
            query.append(" ");

            if (obc != null) {
                query.append("ORDER BY ");
                query.append(obc.getOrderBy());
            } else {
                query.append("ORDER BY ");
                query.append("targetId ASC");
            }

            Query q = session.createQuery(query.toString());
            q.setCacheable(true);

            int queryPos = 0;
            q.setLong(queryPos++, groupId);
            q.setLong(queryPos++, linkType.getType());


            return QueryUtil.list(q, getDialect(), begin, end);
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }


    public List getAllLinksByTarget(LinkType linkType, long targetGroupId, String targetId) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            StringMaker query = new StringMaker();
            query.append(
                    "FROM com.liferay.portlet.journal.model.JournalLink WHERE ");
            query.append("targetGroupId = ?");
            query.append(" AND ");
            query.append("targetId = ?");
            query.append(" AND ");
            query.append("linkType = ?");
            query.append(" ");
            query.append("ORDER BY ");
            query.append("targetId ASC");

            Query q = session.createQuery(query.toString());
            q.setCacheable(true);

            int queryPos = 0;
            q.setLong(queryPos++, targetGroupId);
            q.setString(queryPos++, targetId);
            q.setLong(queryPos++, linkType.getType());

            return q.list();
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public List getAllLinksByTarget(LinkType linkType, long targetGroupId, String targetId, int begin, int end) throws SystemException {
        return getAllLinksByTarget(linkType, targetGroupId, targetId, begin, end, null);
    }

    public List getAllLinksByTarget(LinkType linkType, long targetGroupId, String targetId, int begin, int end, OrderByComparator obc) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            StringMaker query = new StringMaker();
            query.append(
                    "FROM com.liferay.portlet.journal.model.JournalLink WHERE ");
            query.append("targetGroupId = ?");
            query.append(" AND ");
            query.append("targetId = ?");
            query.append(" AND ");
            query.append("linkType = ?");
            query.append(" ");
            query.append(" ");

            if (obc != null) {
                query.append("ORDER BY ");
                query.append(obc.getOrderBy());
            } else {
                query.append("ORDER BY ");
                query.append("targetId ASC");
            }

            Query q = session.createQuery(query.toString());
            q.setCacheable(true);

            int queryPos = 0;
            q.setLong(queryPos++, targetGroupId);
            q.setString(queryPos++, targetId);
            q.setLong(queryPos++, linkType.getType());


            return QueryUtil.list(q, getDialect(), begin, end);
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public JournalLink getLinkByTargetIdAndGroupId(String targetId, long groupId) throws SystemException {
        Session session = null;
        try {
            session = openSession();

            StringMaker query = new StringMaker();
            query.append(
                    "FROM com.liferay.portlet.journal.model.JournalLink WHERE ");
            query.append("groupId = ?");
            query.append(" AND ");
            query.append("targetId = ?");
            query.append(" ");
            query.append("ORDER BY ");
            query.append("targetId ASC");

            Query q = session.createQuery(query.toString());
            q.setCacheable(true);

            int queryPos = 0;
            q.setLong(queryPos++, groupId);
            q.setString(queryPos++, targetId);

            List results = q.list();
            if (results.size() > 0) {
                return (JournalLink) results.get(0);
            }
            return null;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }


    public int countByG_T(long groupId, String targetId)
        throws SystemException {
        Session session = null;

        try {
            session = openSession();

            StringMaker query = new StringMaker();
            query.append("SELECT COUNT(*) ");
            query.append(
                "FROM com.liferay.portlet.journal.model.JournalLink WHERE ");
            query.append("targetGroupId = ?");
            query.append(" AND ");

            if (targetId == null) {
                query.append("targetId IS NULL");
            }
            else {
                query.append("targetId = ?");
            }

            query.append(" ");

            Query q = session.createQuery(query.toString());
            q.setCacheable(true);

            int queryPos = 0;
            q.setLong(queryPos++, groupId);

            if (targetId != null) {
                q.setString(queryPos++, targetId);
            }

            Iterator itr = q.list().iterator();

            if (itr.hasNext()) {
                Long count = (Long)itr.next();

                if (count != null) {
                    return count.intValue();
                }
            }

            return 0;
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }


    public JournalLink findByPrimaryKey(long id)
            throws SystemException, NoSuchShortcutException {
        JournalLink journalLink = fetchByPrimaryKey(id);

        if (journalLink == null) {
            if (_log.isWarnEnabled()) {
                _log.warn("No JournalLink exists with the primary key " +
                        id);
            }

            throw new NoSuchShortcutException(
                    "No JournalLink exists with the primary key " + id);
        }

        return journalLink;
    }


    public JournalLink fetchByPrimaryKey(long id) throws SystemException {
        Session session = null;

        try {
            session = openSession();

            return (JournalLink) session.get(JournalLinkImpl.class,
                    new Long(id));
        }
        catch (Exception e) {
            throw HibernateUtil.processException(e);
        }
        finally {
            closeSession(session);
        }
    }

    public void removeByArticleLinkId(long groupId) throws SystemException, NoSuchShortcutException {
        JournalLink journal = findByPrimaryKey(groupId);
        remove(journal);
    }

    protected void initDao() {
    }

    private static Log _log = LogFactory.getLog(JournalLinkPersistenceImpl.class);
}
