package com.liferay.portlet.journal.service.persistence;

import com.liferay.portal.SystemException;
import com.liferay.portal.model.ModelListener;
import com.liferay.portal.util.PropsUtil;
import com.liferay.portlet.journal.NoSuchArticleException;
import com.liferay.portlet.journal.NoSuchShortcutException;
import com.liferay.portlet.journal.model.JournalLink;
import com.liferay.portlet.journal.service.LinkType;
import com.liferay.util.GetterUtil;
import com.liferay.util.Validator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.List;

/**
 * <a href="JournalArticleUtil.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class JournalLinkUtil {
    public static com.liferay.portlet.journal.model.JournalLink create(long id) {
        return getPersistence().create(id);
    }

    public static com.liferay.portlet.journal.model.JournalLink remove(long id) throws com.liferay.portal.SystemException, NoSuchShortcutException {
        ModelListener listener = _getListener();

        if (listener != null) {
            listener.onBeforeRemove(findByPrimaryKey(id));
        }

        com.liferay.portlet.journal.model.JournalLink journalLink = getPersistence().remove(id);

        if (listener != null) {
            listener.onAfterRemove(journalLink);
        }

        return journalLink;
    }

    public static com.liferay.portlet.journal.model.JournalLink remove(com.liferay.portlet.journal.model.JournalLink journalLink) throws com.liferay.portal.SystemException {
        ModelListener listener = _getListener();

        if (listener != null) {
            listener.onBeforeRemove(journalLink);
        }

        try {
            journalLink = getPersistence().remove(journalLink.getPrimaryKey());
        } catch (NoSuchShortcutException e) {
            e.printStackTrace();
        }

        if (listener != null) {
            listener.onAfterRemove(journalLink);
        }

        return journalLink;
    }

    public static com.liferay.portlet.journal.model.JournalLink update(com.liferay.portlet.journal.model.JournalLink journalLink) throws com.liferay.portal.SystemException {
        ModelListener listener = _getListener();
        boolean isNew = journalLink.isNew();

        if (listener != null) {
            if (isNew) {
                listener.onBeforeCreate(journalLink);
            } else {
                listener.onBeforeUpdate(journalLink);
            }
        }

        journalLink = getPersistence().update(journalLink);

        if (listener != null) {
            if (isNew) {
                listener.onAfterCreate(journalLink);
            } else {
                listener.onAfterUpdate(journalLink);
            }
        }

        return journalLink;
    }

    public static com.liferay.portlet.journal.model.JournalLink update(com.liferay.portlet.journal.model.JournalLink journalLink, boolean saveOrUpdate) throws com.liferay.portal.SystemException {
        ModelListener listener = _getListener();
        boolean isNew = journalLink.isNew();

        if (listener != null) {
            if (isNew) {
                listener.onBeforeCreate(journalLink);
            } else {
                listener.onBeforeUpdate(journalLink);
            }
        }

        journalLink = getPersistence().update(journalLink, saveOrUpdate);

        if (listener != null) {
            if (isNew) {
                listener.onAfterCreate(journalLink);
            } else {
                listener.onAfterUpdate(journalLink);
            }
        }

        return journalLink;
    }

    public static com.liferay.portlet.journal.model.JournalLink findByPrimaryKey(long id) throws com.liferay.portal.SystemException, NoSuchShortcutException {
        return getPersistence().findByPrimaryKey(id);
    }
    public static com.liferay.portlet.journal.model.JournalLink fetchByPrimaryKey(long id) throws com.liferay.portal.SystemException, NoSuchShortcutException {
        return findByPrimaryKey(id);
    }

    public static List fetchByGroupId(LinkType linkType, long groupId) throws SystemException {
        return getPersistence().findByGroupId(linkType,groupId);
    }


    public static List getAllLinksByTarget(LinkType linkType, long targetGroupId, String targetId) throws SystemException {
        return getPersistence().getAllLinksByTarget(linkType,targetGroupId,targetId);
    }


    public static JournalLink fetchByTargetIdAndGroupId(String deleteStructureId, long groupId) throws SystemException {
        return getPersistence().getLinkByTargetIdAndGroupId(deleteStructureId,groupId);
    }


     public static int countByG_T(long groupId, String targetId) throws SystemException {
         return getPersistence().countByG_T(groupId,targetId);
    }


    public static JournalLinkPersistence getPersistence() {
        return _getUtil()._persistence;
    }

    public void setPersistence(JournalLinkPersistence persistence) {
        _persistence = persistence;
    }

    private static JournalLinkUtil _getUtil() {
        if (_util == null) {
            _util = (JournalLinkUtil) com.liferay.portal.kernel.bean.BeanLocatorUtil.locate(_UTIL);
        }

        return _util;
    }

    private static ModelListener _getListener() {
        if (Validator.isNotNull(_LISTENER)) {
            try {
                return (ModelListener) Class.forName(_LISTENER).newInstance();
            }
            catch (Exception e) {
                _log.error(e);
            }
        }

        return null;
    }

    private static final String _UTIL = JournalLinkUtil.class.getName();
    private static final String _LISTENER = GetterUtil.getString(PropsUtil.get(
            "value.object.listener.com.liferay.portlet.journal.model.JournalLink"));
    private static Log _log = LogFactory.getLog(JournalLinkUtil.class);
    private static JournalLinkUtil _util;
    private JournalLinkPersistence _persistence;



}
