/**
 * Copyright (c) 2000-2007 Liferay, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.liferay.portlet.journalcontent.action;

import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.portlet.ConfigurationAction;
import com.liferay.portal.kernel.util.Constants;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.model.Layout;
import com.liferay.portal.theme.ThemeDisplay;
import com.liferay.portal.util.WebKeys;
import com.liferay.portlet.PortletPreferencesFactoryUtil;
import com.liferay.portlet.journal.NoSuchArticleException;
import com.liferay.portlet.journal.model.JournalArticleExternalData;
import com.liferay.portlet.journal.service.JournalArticleExternalDataLocalServiceUtil;
import com.liferay.portlet.journal.service.JournalContentSearchLocalServiceUtil;
import com.liferay.portlet.journalcontent.util.JournalContentUtil;
import com.liferay.util.servlet.SessionErrors;

import javax.portlet.*;

/**
 * <a href="ConfigurationActionImpl.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class ConfigurationActionImpl implements ConfigurationAction {

    public void processAction(
            PortletConfig config, ActionRequest req, ActionResponse res)
            throws Exception {

        try {
            String cmd = ParamUtil.getString(req, Constants.CMD);

            if (!cmd.equals(Constants.UPDATE)) {
                return;
            }

            ThemeDisplay themeDisplay =
                    (ThemeDisplay) req.getAttribute(WebKeys.THEME_DISPLAY);

            long groupId = ParamUtil.getLong(req, "groupId");
            String articleId = ParamUtil.getString(
                    req, "articleId").toUpperCase();
            String templateId = ParamUtil.getString(
                    req, "templateId").toUpperCase();
            long structureGroupId = 0;
            String languageId = LanguageUtil.getLanguageId(req);

            JournalArticleExternalData jaed = null;
                        try {
                            jaed = JournalArticleExternalDataLocalServiceUtil.getArticleExternalData(groupId, articleId);
                            if (jaed != null) {
                                structureGroupId = jaed.getStructureGroupId();
                            }
                        } catch (NoSuchArticleException ex) {
                            //bla bla
                        }

                        if (structureGroupId == 0) {
                            structureGroupId = groupId;
                        }

            boolean disableCaching = ParamUtil.getBoolean(
                    req, "disableCaching");

            String content = JournalContentUtil.getContent(
                    groupId, structureGroupId, articleId, templateId, languageId, themeDisplay,
                    disableCaching);

            if (Validator.isNull(content)) {
                throw new NoSuchArticleException();
            }

            boolean showAvailableLocales = ParamUtil.getBoolean(
                    req, "showAvailableLocales");
            boolean enableRatings = ParamUtil.getBoolean(req, "enableRatings");
            boolean enableComments = ParamUtil.getBoolean(
                    req, "enableComments");

            String portletResource = ParamUtil.getString(
                    req, "portletResource");

            PortletPreferences prefs =
                    PortletPreferencesFactoryUtil.getPortletSetup(
                            req, portletResource, true, true);

            prefs.setValue("group-id", String.valueOf(groupId));
            prefs.setValue("article-id", articleId);
            prefs.setValue("template-id", templateId);
            prefs.setValue("disable-caching", String.valueOf(disableCaching));
            prefs.setValue(
                    "show-available-locales", String.valueOf(showAvailableLocales));
            prefs.setValue("enable-ratings", String.valueOf(enableRatings));
            prefs.setValue("enable-comments", String.valueOf(enableComments));

            prefs.store();

            updateContentSearch(req, portletResource, articleId);

            res.sendRedirect(ParamUtil.getString(req, "redirect"));
        }
        catch (NoSuchArticleException nsae) {
            SessionErrors.add(req, nsae.getClass().getName());
        }
    }

    public String render(
            PortletConfig config, RenderRequest req, RenderResponse res)
            throws Exception {

        return "/html/portlet/journal_content/configuration.jsp";
    }

    protected void updateContentSearch(
            ActionRequest req, String portletResource, String articleId)
            throws Exception {

        ThemeDisplay themeDisplay =
                (ThemeDisplay) req.getAttribute(WebKeys.THEME_DISPLAY);

        Layout layout = themeDisplay.getLayout();

        JournalContentSearchLocalServiceUtil.updateContentSearch(
                layout.getGroupId(), layout.isPrivateLayout(), layout.getLayoutId(),
                portletResource, articleId);
    }

}